@@ -56,7 +56,8 @@ maxTrigger=120
 
 
 Light_Sleep_Level=70
-Deep_Sleep_Level=30
+
+Deep_Sleep_Level=35
 
 
 demo=0
@@ -126,7 +127,6 @@ arrRecordFiles=[]
 arrRecordFilesIndex=0
 RecordFileSelectedDate=""
 
-#global QtGui
 
 #Colors
 MovementBarColor="#DFAD09" #"Yellow"
@@ -145,10 +145,10 @@ Awake_Color=                "#860000" #red
 Awake_ColorDark=         "#4C0000"
 
 
+Sleep_Pattern_Yoffset= 0  #move blue graph x pixel down (cut bottom off)
 
 
-
-noiseReduction=4 #Smoothing of derivation data
+noiseReduction=4  #Smoothing of derivation data
 
 FilterScale=40
 limitMovement=250
