@@ -144,7 +144,10 @@ def ProcessData(ProcessAll=False, ShowFiltered=False):  #DERIVATION (ABLEITUNG)
 
 
 
-def FilterData():
+
+
+
+def Generate_Sleep_Pattern():
     #NOTE:
     #records.arrData has strings and integers mixed. This is ok in python, but does not work in C.
     #So we have to export the data and import it again afterwarts:
@@ -154,7 +157,8 @@ def FilterData():
 
     #Exported function:
 #    arrRet=mylib.sleep_filter(arfunctions_record.pyrSend, records.Index-data.Derivation, filter_data.arrFilter, filter_data.FilterShift, (61-data.FilterScale)*100, data.Ysize-7, 13, data.limitMovement)
-    arrRet=mylib.sleep_filter(arrSend, records.Index-data.Derivation, filter_data.arrFilter, filter_data.FilterShift, data.FilterScale, data.Ysize-7, 13, data.limitMovement)
+#sleep_filter(ar, len, filter,  shift, Yscale, Yoffset, Ymax, Ymin, limitMovement)
+    arrRet=mylib.sleep_filter(arrSend, records.Index-data.Derivation, filter_data.arrFilter, filter_data.FilterShift, data.FilterScale, data.Sleep_Pattern_Yoffset, data.Ysize-7, 13, data.limitMovement)
 
     for i in range(0,  records.Index-data.Derivation): #copy array and scale
         records.arrData[6][i]  = arrRet[i]
@@ -357,18 +361,6 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
 
 
 
-#            #Fix: Erase Time line at his pixel
-#            if(peak>data.Trigger):
-#                paint.setPen(QtGui.QColor(data.GraphBackground))
-#                paint.drawLine(x, data.Ysize-11, x, data.Ysize-1)  #Erase Time line at his pixel
-#                paint.setPen(QtGui.QColor(data.MovementBarColor))
-#    #            print "Peak:", i,  x
-
-
-
-
-
-
         #DRAW sleep graph (blue)
         if(ShowFiltered==True):
             pen=QtGui.QPen()
@@ -382,7 +374,8 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
             for p in range(0,  records.Index-data.Derivation-Xscale,  Xscale):
                 i=p-GraphStart_index
                 x=i/Xscale+1
-                paint.drawLine(x, data.Ysize-16,       x, data.Ysize-records.arrData[6][p+Xscale]-5)
+                y=data.Ysize-records.arrData[6][p+Xscale]-5
+                paint.drawLine(x, data.Ysize-16,       x, y)
 #                print p, records.arrData[0][p+Xscale], records.arrData[6][p+Xscale]
 
             #outline
@@ -392,7 +385,9 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
             for p in range(0,  records.Index-data.Derivation-Xscale,  Xscale):
                 i=p-GraphStart_index
                 x=i/Xscale+1
-                paint.drawLine(x, data.Ysize-records.arrData[6][p]-5,       x+1, data.Ysize-records.arrData[6][p+Xscale]-5)
+                y0=data.Ysize-records.arrData[6][p]-5
+                y1=data.Ysize-records.arrData[6][p+Xscale]-5
+                paint.drawLine(x, y0,       x+1, y1)
 #                paint.drawLine(x, data.Ysize-records.arrData[6][p],       x+1, data.Ysize-records.arrData[6][p+Xscale])
 #                print records.arrData[6][p+Xscale], data.Ysize-records.arrData[6][p+Xscale]-5
 
