@@ -249,7 +249,7 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
     r=GetSensorData()
     if(r==1): #new data got added to array
         ProcessData(False,  False)
-        FilterData() #new: generate blue graph always
+        Generate_Sleep_Pattern() #new: generate blue graph always
         ProcessAlarm()
 
         WriteRecord()
@@ -260,7 +260,7 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
         data.ScrollToEnd=True
         if(data.DisplayIsOn==True): #when display is on, update graph
             GenerateStatisticData()
-#            FilterData()
+#            Generate_Sleep_Pattern()
             Generate_and_show_GraphBitmap(RecordWindow, True) #New: show blue graph
 #            Generate_and_show_GraphBitmap(RecordWindow, False)
 
@@ -299,6 +299,10 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
             data.LastRecord=data.RecordFilename #set to corrent file for viewwindow
             config.set('main', 'LastRecord', str(data.LastRecord))
             print "Show record in ViewWindow:",  data.LastRecord
+            GenerateStatisticData()
+            ProcessData(False,  False)
+            Generate_Sleep_Pattern()
+            Generate_and_show_GraphBitmap(RecordWindow, True) #New: show blue graph
             StartWindow.ShowViewWindow()
             RecordWindow.hide()
 
@@ -1056,7 +1060,7 @@ class frmViewWindow(QMainWindow):
 
         self.ui.lblStatus.setText(_("Rendering data..."))
         app.processEvents() #force ui update
-        FilterData()
+        Generate_Sleep_Pattern()
 
         self.ui.lblStatus.setText(_("Generating statistic..."))
         app.processEvents() #force ui update
@@ -1387,6 +1391,7 @@ class frmConfigWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.SlrDelayStart,SIGNAL("valueChanged(int)"),self.DelaySliderMoved)
         QtCore.QObject.connect(self.ui.SlrYscale_Movement,SIGNAL("valueChanged(int)"),self.YscaleSliderMoved_Movement)
         QtCore.QObject.connect(self.ui.SlrYscale_Sleep,SIGNAL("valueChanged(int)"),self.YscaleSliderMoved_Sleep)
+        QtCore.QObject.connect(self.ui.SlrYoffset_Sleep,SIGNAL("valueChanged(int)"),self.YoffsetSliderMoved_Sleep)
 
 
         QtCore.QObject.connect(self.ui.bOK, QtCore.SIGNAL("clicked()"), self.OK)
@@ -1404,6 +1409,7 @@ class frmConfigWindow(QMainWindow):
         self.ui.lblDelayStart.setText(_("Start delay:"))
         self.ui.lblYscale_Movement.setText(_("Y scaling movement (yellow):"))
         self.ui.lblYscale_Sleep.setText(_("Y scaling sleep graph (blue):"))
+        self.ui.lblYoffset_Sleep.setText(_("Y offset sleep graph (blue):"))
         self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_Advanced), _("Advanced"))
         self.ui.lblMore.setText(_("More settings can be changed at your own risk in the file\n~/.SleepAnalyer/SleepAnalyser.conf."))
         self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_More), _("More"))
@@ -1429,10 +1435,12 @@ class frmConfigWindow(QMainWindow):
         self.ui.lblYscale_Movement.setText(_("Y scaling movement (yellow):")+" "+str(data.Yscale))
         self.ui.SlrYscale_Movement.setValue(int(data.Yscale))
 
-
         self.ui.lblYscale_Sleep.setText(_("Y scaling sleep graph (blue):")+" "+str(data.FilterScale))
         self.ui.SlrYscale_Sleep.setValue(int(data.FilterScale))
 
+        self.ui.lblYoffset_Sleep.setText(_("Y offset sleep graph (blue):")+" "+str(data.Sleep_Pattern_Yoffset))
+        self.ui.SlrYoffset_Sleep.setValue(int(data.Sleep_Pattern_Yoffset))
+
 
 
 #    def Cancel(self):
@@ -1485,6 +1493,7 @@ class frmConfigWindow(QMainWindow):
         config.set('main', 'DelayStartTime', str(data.DelayStartTime))
         config.set('main', 'Yscale', str(data.Yscale))
         config.set('main', 'FilterScale', str(data.FilterScale))
+        config.set('main', 'Sleep_Pattern_Yoffset', str(data.Sleep_Pattern_Yoffset))
 
 
 
@@ -1523,6 +1532,15 @@ class frmConfigWindow(QMainWindow):
         self.ui.lblYscale_Sleep.setText(_("Y scaling sleep graph (blue):")+" "+str(data.FilterScale))
 
 
+    ###########################################################################
+    ##
+    ###########################################################################
+    def YoffsetSliderMoved_Sleep(self): ##(Class ConfigWindow)
+        x=self.ui.SlrYoffset_Sleep.value()
+        data.Sleep_Pattern_Yoffset=int(x)
+        self.ui.lblYoffset_Sleep.setText(_("Y offset sleep graph (blue):")+" "+str(data.Sleep_Pattern_Yoffset))
+
+
 
 ###########################################################################
 ## Class for Date Window
@@ -1676,7 +1694,7 @@ class frmAdditionalInfoWindow(QMainWindow):
 
         txt=txt+"<hr>"
         txt=txt+"<b>"+_("Statistics:")+"</b><table CELLPADDING=2>\n" + \
-                "<tr bgcolor=#DCDCDC><td><b>"+_("Time without<br>movement:")+" </b></td>   <td><b>"+_("Total:")+" </b></td>                                     <td><b>"+_("Maximum:")+"</b></td>                                    <td><b>"+_("Count:")+" </b></td>                     <td colspan=2><b>"+_("Time percent:")+"</b></td>\n" + \
+                "<tr bgcolor=#DCDCDC><td></td>   <td><b>"+_("Total:")+" </b></td>                                     <td><b>"+_("Maximum:")+"</b></td>                                    <td><b>"+_("Count:")+" </b></td>                     <td colspan=2><b>"+_("Time percent:")+"</b></td>\n" + \
                 "<tr><td bgcolor=#DCDCDC><b>"+_("Awake")+":</b></td>         <td><nobr>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[0][0]))+ "</nobr></td>    <td><nobr>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[0][2]))+"</nobr></td>    <td>"+str(records.arrStatData[0][1])+"</td>    <td>"+str(records.arrStatData[0][3])+"%</td><td><img src=\""+data.app_path+"img/"+"Awake.png"+"\" width="+str(records.arrStatData[0][3]*2)+" height=25</td></tr>\n" + \
                 "<tr><td bgcolor=#DCDCDC><b>"+_("Light sleep")+":</b></td>         <td><nobr>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[1][0]))+ "</nobr></td>    <td><nobr>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[1][2]))+"</nobr></td>    <td>"+str(records.arrStatData[1][1])+"</td>    <td>"+str(records.arrStatData[1][3])+"%</td><td><img src=\""+data.app_path+"img/"+"Light_Sleep.png"+"\" width="+str(records.arrStatData[1][3]*2)+" height=25</td></tr>\n" + \
                 "<tr><td bgcolor=#DCDCDC><b>"+_("Deep sleep")+":</b></td>        <td><nobr>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[2][0]))+"</nobr></td>    <td><nobr>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[2][2]))+"</nobr></td>    <td>"+str(records.arrStatData[2][1])+"</td>    <td>"+str(records.arrStatData[2][3])+"%</td><td><img src=\""+data.app_path+"img/"+"Deep_Sleep.png"+"\" width="+str(records.arrStatData[2][3]*2)+" height=25</td></tr>\n" + \
@@ -2141,4 +2159,4 @@ def GenerateStatisticsBitmap(self):
 
 
 ###########################################################################
-main() # Now we can start it.
\ No newline at end of file
+main() # Now we can start it.
