@@ -23,12 +23,11 @@ LastIndex=-1 #maximum from Index and AlarmTimeWindowEnd index
 
 
 
-arrStatData=[[0]*4,  [0]*4,  [0]*4,  [0]*4]
+arrStatData=[[0]*4,  [0]*4,  [0]*4]
 #field 1:
-    # sleep state 1 (>30 min)
-    # sleep state 2 (>15 min)
-    # sleep state 3 (>7 min)
-    # sleep state 4 (<30 min)
+    # Awake time
+    # Light sleep
+    # Deep Sleep
 #field 2:
     # Accumulated time/phase, Amount of times/phase, Max time/phase, time percent
 
